==> owncloud-8.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/da.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Lagerplads er ikke tilgængeligt",
    "Storage invalid" : "Lagerplads er ugyldig",
    "Unknown error" : "Ukendt fejl",
    "Could not move %s - File with this name already exists" : "Kunne ikke flytte %s - der findes allerede en fil med dette navn",
    "Could not move %s" : "Kunne ikke flytte %s",
    "Permission denied" : "Adgang nægtet",
    "The target folder has been moved or deleted." : "Mappen er blevet slettet eller fjernet.",
    "The name %s is already used in the folder %s. Please choose a different name." : "Navnet %s er allerede i brug i mappen %s. Vælg venligst et andet navn.",
    "Error when creating the file" : "Fejl ved oprettelse af fil",
    "Error when creating the folder" : "Fejl ved oprettelse af mappen",
    "Unable to set upload directory." : "Ude af stand til at vælge upload mappe.",
    "Invalid Token" : "Ugyldig Token ",
    "No file was uploaded. Unknown error" : "Ingen fil blev uploadet. Ukendt fejl.",
    "There is no error, the file uploaded with success" : "Der skete ingen fejl, filen blev succesfuldt uploadet",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
    "The uploaded file was only partially uploaded" : "Filen blev kun delvist uploadet.",
    "No file was uploaded" : "Ingen fil uploadet",
    "Missing a temporary folder" : "Manglende midlertidig mappe.",
    "Failed to write to disk" : "Fejl ved skrivning til disk.",
    "Not enough storage available" : "Der er ikke nok plads til rådlighed",
    "Upload failed. Could not find uploaded file" : "Upload fejlede. Kunne ikke finde den uploadede fil.",
    "Upload failed. Could not get file info." : "Upload fejlede. Kunne ikke hente filinformation.",
    "Invalid directory." : "Ugyldig mappe.",
    "Files" : "Filer",
    "All files" : "Alle filer",
    "Favorites" : "Foretrukne",
    "Home" : "Hjemme",
    "Close" : "Luk",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke upload {filename} da det er enten en mappe eller indholder 0 bytes.",
    "Total file size {size1} exceeds upload limit {size2}" : "Den totale filstørrelse {size1} er større end uploadgrænsen {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Der er ikke tilstrækkeligt friplads. Du uplaoder {size1} men der er kun {size2} tilbage",
    "Upload cancelled." : "Upload afbrudt.",
    "Could not get result from server." : "Kunne ikke hente resultat fra server.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fil upload kører. Hvis du forlader siden nu, vil uploadet blive annuleret.",
    "Actions" : "Handlinger",
    "Download" : "Download",
    "Rename" : "Omdøb",
    "Delete" : "Slet",
    "Details" : "Detaljer",
    "Select" : "Vælg",
    "Pending" : "Afventer",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "This operation is forbidden" : "Denne operation er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappe er utilgængelig, tjek venligst loggene eller kontakt administratoren",
    "Error moving file." : "Fejl ved flytning af fil",
    "Error moving file" : "Fejl ved flytning af fil",
    "Error" : "Fejl",
    "{new_name} already exists" : "{new_name} eksisterer allerede",
    "Could not rename file" : "Kunne ikke omdøbe filen",
    "Could not create file" : "Kunne ikke oprette fil",
    "Could not create folder" : "Kunne ikke oprette mappe",
    "Error deleting file." : "Fejl ved sletnign af fil.",
    "No entries in this folder match '{filter}'" : "Der er ingen poster i denne mappe, der matcher '{filter}'",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Ændret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "You don’t have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploader %n fil","Uploader %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "'{name}' er et ugyldigt filnavn.",
    "File name cannot be empty." : "Filnavnet kan ikke stå tomt.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opbevaringspladsen tilhørende {owner} er fyldt op - filer kan ikke længere opdateres eller synkroniseres!",
    "Your storage is full, files can not be updated or synced anymore!" : "Din opbevaringsplads er fyldt op, filer kan ikke opdateres eller synkroniseres længere!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opbevaringspladsen tilhørende {owner} er næsten fyldt op ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Din opbevaringsplads er næsten fyldt op ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["match '{filter}'","match '{filter}'"],
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Gjort til foretrukken",
    "Favorite" : "Foretrukken",
    "{newname} already exists" : "{newname} eksistere allerede",
    "Upload" : "Upload",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekst file.txt",
    "Folder" : "Mappe",
    "New folder" : "Ny Mappe",
    "An error occurred while trying to update the tags" : "Der opstod en fejl under forsøg på at opdatere mærkerne",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapper er blevet <strong>oprettet</strong>",
    "A file or folder has been <strong>changed</strong>" : "En fil eller mappe er blevet <strong>ændret</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begræns noter om oprettelse og ændringer af dine <strong>favorit filer</strong> <em>(Kun streaming)</em>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe er blevet <strong>slettet</strong>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe er blevet <strong>gendannet</strong>",
    "You created %1$s" : "Du oprettede %1$s ",
    "%2$s created %1$s" : "%2$s oprettede %1$s",
    "%1$s was created in a public folder" : "%1$s blev oprettet i en offentlig mappe",
    "You changed %1$s" : "Du ændrede %1$s",
    "%2$s changed %1$s" : "%2$s ændrede %1$s",
    "You deleted %1$s" : "Du slettede %1$s",
    "%2$s deleted %1$s" : "%2$s slettede %1$s",
    "You restored %1$s" : "Du gendannede %1$s",
    "%2$s restored %1$s" : "%2$s gendannede %1$s",
    "%s could not be renamed as it has been deleted" : "%s kunne ikke omdøbes, da den er blevet slettet",
    "%s could not be renamed" : "%s kunne ikke omdøbes",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "Filhåndtering",
    "Maximum upload size" : "Maksimal upload-størrelse",
    "max. possible: " : "max. mulige: ",
    "With PHP-FPM this value may take up to 5 minutes to take effect after saving." : "Med denne PHP-FPM værdi, kan der gå op til 5 minutter før virkningen indtræffer, efter at der gemmes.",
    "Save" : "Gem",
    "Can not be edited from here due to insufficient permissions." : "Kan ikke redigeres herfra på grund af utilstrækkelige rettigheder.",
    "Settings" : "Indstillinger",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Brug denne adresse for at <a href=\"%s\" target=\"_blank\">tilgå dine filer via WebDAV</a>",
    "Cancel upload" : "Fortryd upload",
    "No files in here" : "Her er ingen filer",
    "Upload some content or sync with your devices!" : "Overfør indhold eller synkronisér med dine enheder!",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Select all" : "Vælg alle",
    "Upload too large" : "Upload er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerne, du prøver at uploade, er større end den maksimale størrelse for fil-upload på denne server.",
    "Files are being scanned, please wait." : "Filerne bliver indlæst, vent venligst.",
    "Currently scanning" : "Skanning er i gang",
    "No favorites" : "Ingen foretrukne",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du har markeret som foretrukne, vil blive vist her"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/da.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Lagerplads er ikke tilgængeligt",
    "Storage invalid" : "Lagerplads er ugyldig",
    "Unknown error" : "Ukendt fejl",
    "Unable to set upload directory." : "Ude af stand til at vælge upload mappe.",
    "Invalid Token" : "Ugyldig Token ",
    "No file was uploaded. Unknown error" : "Ingen fil blev uploadet. Ukendt fejl.",
    "There is no error, the file uploaded with success" : "Der skete ingen fejl, filen blev succesfuldt uploadet",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Den uploadede fil overstiger upload_max_filesize direktivet i php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Den uploadede fil overstiger MAX_FILE_SIZE indstilingen, som specificeret i HTML formularen",
    "The uploaded file was only partially uploaded" : "Filen blev kun delvist uploadet.",
    "No file was uploaded" : "Ingen fil uploadet",
    "Missing a temporary folder" : "Manglende midlertidig mappe.",
    "Failed to write to disk" : "Fejl ved skrivning til disk.",
    "Not enough storage available" : "Der er ikke nok plads til rådlighed",
    "The target folder has been moved or deleted." : "Mappen er blevet slettet eller fjernet.",
    "Upload failed. Could not find uploaded file" : "Upload fejlede. Kunne ikke finde den uploadede fil.",
    "Upload failed. Could not get file info." : "Upload fejlede. Kunne ikke hente filinformation.",
    "Invalid directory." : "Ugyldig mappe.",
    "Files" : "Filer",
    "All files" : "Alle filer",
    "Favorites" : "Foretrukne",
    "Home" : "Hjemme",
    "Close" : "Luk",
    "Upload cancelled." : "Upload afbrudt.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Kan ikke upload {filename} da det er enten en mappe eller indholder 0 bytes.",
    "Total file size {size1} exceeds upload limit {size2}" : "Den totale filstørrelse {size1} er større end uploadgrænsen {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Der er ikke tilstrækkeligt friplads. Du uplaoder {size1} men der er kun {size2} tilbage",
    "Could not get result from server." : "Kunne ikke hente resultat fra server.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Fil upload kører. Hvis du forlader siden nu, vil uploadet blive annuleret.",
    "Actions" : "Handlinger",
    "Download" : "Download",
    "Rename" : "Omdøb",
    "Delete" : "Slet",
    "Disconnect storage" : "Frakobl lager",
    "Unshare" : "Fjern deling",
    "Details" : "Detaljer",
    "Select" : "Vælg",
    "Pending" : "Afventer",
    "Unable to determine date" : "Kan ikke fastslå datoen",
    "This operation is forbidden" : "Denne operation er forbudt",
    "This directory is unavailable, please check the logs or contact the administrator" : "Denne mappe er utilgængelig, tjek venligst loggene eller kontakt administratoren",
    "No entries in this folder match '{filter}'" : "Der er ingen poster i denne mappe, der matcher '{filter}'",
    "Name" : "Navn",
    "Size" : "Størrelse",
    "Modified" : "Ændret",
    "_%n folder_::_%n folders_" : ["%n mappe","%n mapper"],
    "_%n file_::_%n files_" : ["%n fil","%n filer"],
    "{dirs} and {files}" : "{dirs} og {files}",
    "You don’t have permission to upload or create files here" : "Du har ikke tilladelse til at uploade eller oprette filer her",
    "_Uploading %n file_::_Uploading %n files_" : ["Uploader %n fil","Uploader %n filer"],
    "New" : "Ny",
    "\"{name}\" is an invalid file name." : "'{name}' er et ugyldigt filnavn.",
    "File name cannot be empty." : "Filnavnet kan ikke stå tomt.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Opbevaringspladsen tilhørende {owner} er fyldt op - filer kan ikke længere opdateres eller synkroniseres!",
    "Your storage is full, files can not be updated or synced anymore!" : "Din opbevaringsplads er fyldt op, filer kan ikke opdateres eller synkroniseres længere!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Opbevaringspladsen tilhørende {owner} er næsten fyldt op ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Din opbevaringsplads er næsten fyldt op ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["match '{filter}'","match '{filter}'"],
    "Path" : "Sti",
    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
    "Favorited" : "Gjort til foretrukken",
    "Favorite" : "Foretrukken",
    "Folder" : "Mappe",
    "New folder" : "Ny Mappe",
    "{newname} already exists" : "{newname} eksistere allerede",
    "Upload" : "Upload",
    "An error occurred while trying to update the tags" : "Der opstod en fejl under forsøg på at opdatere mærkerne",
    "A new file or folder has been <strong>created</strong>" : "En ny fil eller mapper er blevet <strong>oprettet</strong>",
    "A file or folder has been <strong>changed</strong>" : "En fil eller mappe er blevet <strong>ændret</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Begræns noter om oprettelse og ændringer af dine <strong>favorit filer</strong> <em>(Kun streaming)</em>",
    "A file or folder has been <strong>deleted</strong>" : "En fil eller mappe er blevet <strong>slettet</strong>",
    "A file or folder has been <strong>restored</strong>" : "En fil eller mappe er blevet <strong>gendannet</strong>",
    "You created %1$s" : "Du oprettede %1$s ",
    "%2$s created %1$s" : "%2$s oprettede %1$s",
    "%1$s was created in a public folder" : "%1$s blev oprettet i en offentlig mappe",
    "You changed %1$s" : "Du ændrede %1$s",
    "%2$s changed %1$s" : "%2$s ændrede %1$s",
    "You deleted %1$s" : "Du slettede %1$s",
    "%2$s deleted %1$s" : "%2$s slettede %1$s",
    "You restored %1$s" : "Du gendannede %1$s",
    "%2$s restored %1$s" : "%2$s gendannede %1$s",
    "Changed by %2$s" : "Ændret af %2$s",
    "Deleted by %2$s" : "Slettet af %2$s",
    "Restored by %2$s" : "Gendannet af %2$s",
    "Upload (max. %s)" : "Upload (max. %s)",
    "File handling" : "Filhåndtering",
    "Maximum upload size" : "Maksimal upload-størrelse",
    "max. possible: " : "max. mulige: ",
    "Save" : "Gem",
    "Settings" : "Indstillinger",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "Brug denne adresse for at <a href=\"%s\" target=\"_blank\">tilgå dine filer via WebDAV</a>",
    "Cancel upload" : "Fortryd upload",
    "No files in here" : "Her er ingen filer",
    "Upload some content or sync with your devices!" : "Overfør indhold eller synkronisér med dine enheder!",
    "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
    "Select all" : "Vælg alle",
    "Upload too large" : "Upload er for stor",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Filerne, du prøver at uploade, er større end den maksimale størrelse for fil-upload på denne server.",
    "No favorites" : "Ingen foretrukne",
    "Files and folders you mark as favorite will show up here" : "Filer og mapper som du har markeret som foretrukne, vil blive vist her",
    "Text file" : "Tekstfil",
    "New text file.txt" : "Ny tekst file.txt",
    "Changed by %2$s" : "Ændret af %2$s",
    "Deleted by %2$s" : "Slettet af %2$s",
    "Restored by %2$s" : "Gendannet af %2$s",
    "You changed %1$s" : "Du ændrede %1$s",
    "You created %1$s" : "Du oprettede %1$s ",
    "You deleted %1$s" : "Du slettede %1$s",
    "You restored %1$s" : "Du gendannede %1$s"
},
"nplurals=2; plural=(n != 1);");
